@@ -1,3 +1,5 @@
+use crypto_market_type::MarketType;
+
 pub(crate) fn normalize_pair(symbol: &str) -> Option<String> {
     if symbol.ends_with("-PERPETUAL") {
         // inverse_swap
@@ -17,3 +19,15 @@ pub(crate) fn normalize_pair(symbol: &str) -> Option<String> {
         None
     }
 }
+
+pub(crate) fn get_market_type(symbol: &str) -> MarketType {
+    if symbol.ends_with("-PERPETUAL") {
+        MarketType::InverseSwap
+    } else if symbol.len() > 7 && (&symbol[(symbol.len() - 2)..]).parse::<i64>().is_ok() {
+        MarketType::InverseFuture
+    } else if symbol.ends_with("-P") || symbol.ends_with("-C") {
+        MarketType::EuropeanOption
+    } else {
+        MarketType::Unknown
+    }
+}
