@@ -1,6 +1,7 @@
 mod utils;
 
-use crypto_pair::{normalize_currency, normalize_pair};
+use crypto_market_type::MarketType;
+use crypto_pair::{get_market_type, normalize_currency, normalize_pair};
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::collections::HashMap;
@@ -46,5 +47,13 @@ fn verify_swap_symbols() {
         );
 
         assert_eq!(pair.as_str(), pair_expected);
+
+        let market_type = get_market_type(&market.name, EXCHANGE_NAME, None);
+        println!("{}", market_type);
+        assert!(
+            market_type == MarketType::LinearSwap
+                || market_type == MarketType::InverseSwap
+                || market_type == MarketType::InverseFuture
+        );
     }
 }
